invoke abstract method
deadline is how long the caller intends to wait for a long-poll command.
Transports that cannot be torn down by one slow request may ignore it.
Implementation
Future<Map<String, Object?>> invoke({
required String command,
required Map<String, Object?> arguments,
String? requestId,
Duration? deadline,
});