serverVersion property
The patchbay package version the host was built from, or null when the
host does not report one.
Implementation
final String? serverVersion;
The patchbay package version the host was built from, or null when the
host does not report one.
final String? serverVersion;