PatchbaySnapshotDiffClient class abstract interface

Optional client surface for the separately capability-gated diff request.

Kept out of PatchbayClient so adding PB-040-10 does not break third-party test or transport adapters that implemented the published 0.3 interface.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
snapshotDiff({required int fromRevision}) Future<Map<String, Object?>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited